Package: WDI
Title: World Development Indicators and Other World Bank Data
Description: Search and download data from over 40 databases hosted by the World Bank, including the World Development Indicators ('WDI'), International Debt Statistics, Doing Business, Human Capital Index, and Sub-national Poverty indicators.
Authors@R: c(
    person("Vincent", "Arel-Bundock",
           email = "vincent.arel-bundock@umontreal.ca",
           role = c("aut", "cre"),
           comment = c(ORCID = "0000-0003-2042-7063")),
    person("Etienne", "Bacher",
           email = "etienne.bacher@protonmail.com",
           role = "ctb"))
Maintainer: Vincent Arel-Bundock <vincent.arel-bundock@umontreal.ca>
LazyData: yes
Type: Package
LazyLoad: yes
Encoding: UTF-8
Version: 2.7.10
URL: https://vincentarelbundock.github.io/WDI/
BugReports: https://github.com/vincentarelbundock/WDI/issues
Depends: R (>= 3.5.0)
Imports: jsonlite
Suggests: altdoc, curl, testthat, tidyr (>= 0.8.0)
RoxygenNote: 7.3.2
License: GPL-3
NeedsCompilation: no
Packaged: 2026-04-05 10:56:10 UTC; vincent
Author: Vincent Arel-Bundock [aut, cre] (ORCID:
    <https://orcid.org/0000-0003-2042-7063>),
  Etienne Bacher [ctb]
Repository: CRAN
Date/Publication: 2026-04-05 11:30:02 UTC
Built: R 4.5.2; ; 2026-04-08 01:06:27 UTC; unix
