% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/WDI.R
\name{wdi.dl}
\alias{wdi.dl}
\title{Internal function to download data}
\usage{
wdi.dl(
  indicator,
  country,
  start,
  end,
  latest = NULL,
  language = "en",
  extra = FALSE
)
}
\description{
Internal function to download data
}
\keyword{internal}
